textformatter
=============

Format text into readable text


Installation
------------------
textformatter is available from [PyPI](https://pypi.python.org/pypi/feature-formatter) and can be installed using pip.
```
pip install feature-formatter
```

Q&A
-----------------
TBD
